@@ -1,6 +1,6 @@
 /*
  * sadf_misc.c: Funtions used by sadf to display special records
- * (C) 2011-2020 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2011-2021 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -41,7 +41,7 @@
 
 extern char *tzname[2];
 
-extern unsigned int flags;
+extern uint64_t flags;
 extern char *seps[];
 
 extern int palette;
